import { ITokens, APIResponse, ContentTypeDescription, ContentItemPublicContract, SearchResultOfContentItemPublicContract, NewsArticleRssResponse } from "../../types";
export declare class Content {
    private url;
    private headers;
    constructor(url: string, headers: Record<string, string>);
    /**
     * Gets an object describing a particular variant of content.
     * @param type
     * @returns Gets an object describing a particular variant of content.
     */
    GetContentType(type: string, tokens?: ITokens): Promise<APIResponse<ContentTypeDescription>>;
    /**
     * Returns a content item referenced by id
     * @param head false
     * @param id
     * @param locale
     * @returns Returns a content item referenced by id
     */
    GetContentById(id: string, locale: string, queryString: {
        head?: boolean;
    } | null, tokens?: ITokens): Promise<APIResponse<ContentItemPublicContract>>;
    /**
     * Returns the newest item that matches a given tag and Content Type.
     * @param head Not used.
     * @param locale
     * @param tag
     * @param type
     * @returns Returns the newest item that matches a given tag and Content Type.
     */
    GetContentByTagAndType(locale: string, tag: string, type: string, queryString: {
        head?: boolean;
    } | null, tokens?: ITokens): Promise<APIResponse<ContentItemPublicContract>>;
    /**
     * Gets content based on querystring information passed in. Provides basic search and text search capabilities.
     * @param ctype Content type tag: Help, News, etc. Supply multiple ctypes separated by space.
     * @param currentpage Page number for the search results, starting with page 1.
     * @param head Not used.
     * @param locale
     * @param searchtext Word or phrase for the search.
     * @param source For analytics, hint at the part of the app that triggered the search. Optional.
     * @param tag Tag used on the content to be searched.
     * @returns Gets content based on querystring information passed in. Provides basic search and text search capabilities.
     */
    SearchContentWithText(locale: string, queryString: {
        ctype?: string;
        currentpage?: number;
        head?: boolean;
        searchtext?: string;
        source?: string;
        tag?: string;
    } | null, tokens?: ITokens): Promise<APIResponse<SearchResultOfContentItemPublicContract>>;
    /**
     * Searches for Content Items that match the given Tag and Content Type.
     * @param currentpage Page number for the search results starting with page 1.
     * @param head Not used.
     * @param itemsperpage Not used.
     * @param locale
     * @param tag
     * @param type
     * @returns Searches for Content Items that match the given Tag and Content Type.
     */
    SearchContentByTagAndType(locale: string, tag: string, type: string, queryString: {
        currentpage?: number;
        head?: boolean;
        itemsperpage?: number;
    } | null, tokens?: ITokens): Promise<APIResponse<SearchResultOfContentItemPublicContract>>;
    /**
     * Search for Help Articles.
     * @param searchtext
     * @param size
     * @returns Search for Help Articles.
     */
    SearchHelpArticles(searchtext: string, size: string, tokens?: ITokens): Promise<APIResponse<object>>;
    /**
     * Returns a JSON string response that is the RSS feed for news articles.
     * @param categoryfilter Optionally filter response to only include news items in a certain category.
     * @param includebody Optionally include full content body for each news item.
     * @param pageToken Zero-based pagination token for paging through result sets.
     * @returns Returns a JSON string response that is the RSS feed for news articles.
     */
    RssNewsArticles(pageToken: string, queryString: {
        categoryfilter?: string;
        includebody?: boolean;
    } | null, tokens?: ITokens): Promise<APIResponse<NewsArticleRssResponse>>;
}
