import { ITokens, APIResponse, CoreSettingsConfiguration, CoreSystem, GlobalAlert } from "../../types";
export declare class Core {
    private url;
    private headers;
    constructor(url: string, headers: Record<string, string>);
    /**
     * List of available localization cultures
     
      * @returns List of available localization cultures
     */
    GetAvailableLocales(tokens?: ITokens): Promise<APIResponse<Record<string, string>>>;
    /**
     * Get the common settings used by the Bungie.Net environment.
     
      * @returns Get the common settings used by the Bungie.Net environment.
     */
    GetCommonSettings(tokens?: ITokens): Promise<APIResponse<CoreSettingsConfiguration>>;
    /**
     * Get the user-specific system overrides that should be respected alongside common systems.
     
      * @returns Get the user-specific system overrides that should be respected alongside common systems.
     */
    GetUserSystemOverrides(tokens?: ITokens): Promise<APIResponse<Record<string, CoreSystem>>>;
    /**
     * Gets any active global alert for display in the forum banners, help pages, etc. Usually used for DOC alerts.
     * @param includestreaming Determines whether Streaming Alerts are included in results
     * @returns Gets any active global alert for display in the forum banners, help pages, etc. Usually used for DOC alerts.
     */
    GetGlobalAlerts(queryString: {
        includestreaming?: boolean;
    } | null, tokens?: ITokens): Promise<APIResponse<GlobalAlert[]>>;
}
