import { ITokens, APIResponse, TrendingCategories, SearchResultOfTrendingEntry, TrendingEntryType, TrendingDetail } from "../../types";
export declare class Trending {
    private url;
    private headers;
    constructor(url: string, headers: Record<string, string>);
    /**
     * Returns trending items for Bungie.net, collapsed into the first page of items per category. For pagination within a category, call GetTrendingCategory.
     
      * @returns Returns trending items for Bungie.net, collapsed into the first page of items per category. For pagination within a category, call GetTrendingCategory.
     */
    GetTrendingCategories(tokens?: ITokens): Promise<APIResponse<TrendingCategories>>;
    /**
     * Returns paginated lists of trending items for a category.
     * @param categoryId The ID of the category for whom you want additional results.
     * @param pageNumber The page # of results to return.
     * @returns Returns paginated lists of trending items for a category.
     */
    GetTrendingCategory(categoryId: string, pageNumber: number, tokens?: ITokens): Promise<APIResponse<SearchResultOfTrendingEntry>>;
    /**
     * Returns the detailed results for a specific trending entry. Note that trending entries are uniquely identified by a combination of *both* the TrendingEntryType *and* the identifier: the identifier alone is not guaranteed to be globally unique.
     * @param identifier The identifier for the entity to be returned.
     * @param trendingEntryType The type of entity to be returned.
     * @returns Returns the detailed results for a specific trending entry. Note that trending entries are uniquely identified by a combination of *both* the TrendingEntryType *and* the identifier: the identifier alone is not guaranteed to be globally unique.
     */
    GetTrendingEntryDetail(identifier: string, trendingEntryType: TrendingEntryType, tokens?: ITokens): Promise<APIResponse<TrendingDetail>>;
}
